API docs for “spamfighter.core.model.test.test_bayes.BayesModelTestCase”

# Class s.c.m.t.t.BayesModelTestCase(unittest.TestCase):

Part of spamfighter.core.model.test.test_bayes View Source View In Hierarchy

Тест на `spamfighter.core.model.dm.BayesModel`.

Method | testInterface | Undocumented
Method | testTrainClassifySimple | Undocumented
Method | testTrainClassify | Undocumented

def testInterface(self): (source)
Undocumented
def testTrainClassifySimple(self): (source)
Undocumented
def testTrainClassify(self): (source)
Undocumented